{%- if has_config %}
from {{ package_name }} import SETTINGS
{%- endif %}

def main():
    {%- if has_config %}
    print(f"Hi from {SETTINGS['project_name']}!")
    {%- else %}
    print("Hi from viperx!")
    {%- endif %}

if __name__ == "__main__":
    main()
